AuthException class

Implemented types

Constructors

AuthException(String body)

Properties

body → String
final
errorCode → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
message → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited