TokenStore class abstract

Implementers

Constructors

TokenStore()

Properties

expiry → DateTime?
no setter
hashCode → int
The hash code for this object.
no setterinherited
hasToken → bool
no setter
idToken → String?
no setter
refreshToken → String?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userId → String?
no setter

Methods

clear() → void
delete() → void
expireToken() → void
Force refresh - useful for testing
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read() → Token?
Restore the refresh token from storage, returns null if token isn't stored
setToken(String? userId, String idToken, String refreshToken, int expiresIn) → void
toString() → String
A string representation of this object.
inherited
write(Token? token) → void
Persist the refresh token

Operators

operator ==(Object other) → bool
The equality operator.
inherited