VolatileStore class

Doesn't actually persist tokens. Useful for testing or in environments where persistence isn't available but it's fine signing in for each session.

Inheritance

Constructors

VolatileStore()

Properties

expiry → DateTime?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hasToken → bool
no setterinherited
idToken → String?
no setterinherited
refreshToken → String?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userId → String?
no setterinherited

Methods

clear() → void
inherited
delete() → void
override
expireToken() → void
Force refresh - useful for testing
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read() → Token?
Restore the refresh token from storage, returns null if token isn't stored
override
setToken(String? userId, String idToken, String refreshToken, int expiresIn) → void
inherited
toString() → String
A string representation of this object.
inherited
write(Token? token) → void
Persist the refresh token
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited