CollectionReference class

Inheritance

Constructors

CollectionReference(FirestoreGateway gateway, String path)
Constructs a CollectionReference using FirestoreGateway and path.

Properties

fullPath → String
no setterinherited
gateway → FirestoreGateway
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
no setterinherited
path → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stream → Stream<List<Document>>
no setter

Methods

add(Map<String, dynamic> map) → Future<Document>
Create a document with a random id.
document(String id) → DocumentReference
get({int pageSize = 1024, String nextPageToken = ''}) → Future<Page<Document>>
limit(int count) → QueryReference
Returns CollectionReference that's additionally limited to only return up to the specified number of documents.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
orderBy(String fieldPath, {bool descending = false}) → QueryReference
Returns CollectionReference that's additionally sorted by the specified fieldPath.
toString() → String
A string representation of this object.
inherited
where(String fieldPath, {dynamic isEqualTo, dynamic isLessThan, dynamic isLessThanOrEqualTo, dynamic isGreaterThan, dynamic isGreaterThanOrEqualTo, dynamic arrayContains, List? arrayContainsAny, List? whereIn, bool isNull = false}) → QueryReference

Operators

operator ==(Object other) → bool
The equality operator.
inherited