GeoPoint class

Constructors

GeoPoint(double latitude, double longitude)
const
GeoPoint.fromLatLng(LatLng value)
Creates the GeoPoint instance using LatLng.

Properties

hashCode → int
The hash code for this object.
no setteroverride
latitude → double
final
longitude → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toLatLng() → LatLng
Creates the LatLng instance corresponding this geo point.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override