QueryReference class

Inheritance

Constructors

QueryReference(FirestoreGateway gateway, String path)

Properties

fullPath → String
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String
no setterinherited
path → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

get() → Future<List<Document>>
limit(int count) → QueryReference
Returns QueryReference that's additionally limited to only return up to the specified number of documents.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
orderBy(String fieldPath, {bool descending = false}) → QueryReference
Returns QueryReference that's additionally sorted by the specified fieldPath.
toString() → String
A string representation of this object.
inherited
where(String fieldPath, {dynamic isEqualTo, dynamic isLessThan, dynamic isLessThanOrEqualTo, dynamic isGreaterThan, dynamic isGreaterThanOrEqualTo, dynamic arrayContains, List? arrayContainsAny, List? whereIn, bool isNull = false}) → QueryReference

Operators

operator ==(Object other) → bool
The equality operator.
inherited